import datetime
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.season_list_by_organization_age_group import SeasonListByOrganizationAgeGroup
from ...models.season_list_by_organization_discipline import SeasonListByOrganizationDiscipline
from ...models.season_list_by_organization_event_type import SeasonListByOrganizationEventType
from ...models.season_list_by_organization_gender import SeasonListByOrganizationGender
from ...models.season_list_by_organization_representation import SeasonListByOrganizationRepresentation
from ...models.season_list_by_organization_response_default import SeasonListByOrganizationResponseDefault
from ...models.season_list_by_organization_season_type import SeasonListByOrganizationSeasonType
from ...models.season_list_by_organization_seasons_response import SeasonListByOrganizationSeasonsResponse
from ...models.season_list_by_organization_standard import SeasonListByOrganizationStandard
from ...models.season_list_by_organization_status import SeasonListByOrganizationStatus
from ...models.season_list_by_organization_video_production import SeasonListByOrganizationVideoProduction
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    *,
    added: Union[Unset, datetime.datetime] = UNSET,
    age_group: Union[Unset, SeasonListByOrganizationAgeGroup] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    discipline: Union[Unset, SeasonListByOrganizationDiscipline] = UNSET,
    end_date: Union[Unset, datetime.date] = UNSET,
    event_type: Union[Unset, SeasonListByOrganizationEventType] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    gender: Union[Unset, SeasonListByOrganizationGender] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    name_latin_contains: Union[Unset, str] = UNSET,
    name_local_contains: Union[Unset, str] = UNSET,
    offset: Union[Unset, int] = UNSET,
    representation: Union[Unset, SeasonListByOrganizationRepresentation] = UNSET,
    season_type: Union[Unset, SeasonListByOrganizationSeasonType] = UNSET,
    sort_by: Union[Unset, str] = UNSET,
    standard: Union[Unset, SeasonListByOrganizationStandard] = UNSET,
    start_date: Union[Unset, datetime.date] = UNSET,
    status: Union[Unset, SeasonListByOrganizationStatus] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    video_production: Union[Unset, SeasonListByOrganizationVideoProduction] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_added: Union[Unset, str] = UNSET
    if not isinstance(added, Unset):
        json_added = added.isoformat()
    params["added"] = json_added

    json_age_group: Union[Unset, str] = UNSET
    if not isinstance(age_group, Unset):
        json_age_group = age_group.value

    params["ageGroup"] = json_age_group

    json_competition_id: Union[Unset, str] = UNSET
    if not isinstance(competition_id, Unset):
        json_competition_id = str(competition_id)
    params["competitionId"] = json_competition_id

    json_discipline: Union[Unset, str] = UNSET
    if not isinstance(discipline, Unset):
        json_discipline = discipline.value

    params["discipline"] = json_discipline

    json_end_date: Union[Unset, str] = UNSET
    if not isinstance(end_date, Unset):
        json_end_date = end_date.isoformat()
    params["endDate"] = json_end_date

    json_event_type: Union[Unset, str] = UNSET
    if not isinstance(event_type, Unset):
        json_event_type = event_type.value

    params["eventType"] = json_event_type

    params["external"] = external

    params["fields"] = fields

    json_gender: Union[Unset, str] = UNSET
    if not isinstance(gender, Unset):
        json_gender = gender.value

    params["gender"] = json_gender

    params["hideNull"] = hide_null

    params["include"] = include

    params["limit"] = limit

    params["nameLatinContains"] = name_latin_contains

    params["nameLocalContains"] = name_local_contains

    params["offset"] = offset

    json_representation: Union[Unset, str] = UNSET
    if not isinstance(representation, Unset):
        json_representation = representation.value

    params["representation"] = json_representation

    json_season_type: Union[Unset, str] = UNSET
    if not isinstance(season_type, Unset):
        json_season_type = season_type.value

    params["seasonType"] = json_season_type

    params["sortBy"] = sort_by

    json_standard: Union[Unset, str] = UNSET
    if not isinstance(standard, Unset):
        json_standard = standard.value

    params["standard"] = json_standard

    json_start_date: Union[Unset, str] = UNSET
    if not isinstance(start_date, Unset):
        json_start_date = start_date.isoformat()
    params["startDate"] = json_start_date

    json_status: Union[Unset, str] = UNSET
    if not isinstance(status, Unset):
        json_status = status.value

    params["status"] = json_status

    json_updated: Union[Unset, str] = UNSET
    if not isinstance(updated, Unset):
        json_updated = updated.isoformat()
    params["updated"] = json_updated

    json_video_production: Union[Unset, str] = UNSET
    if not isinstance(video_production, Unset):
        json_video_production = video_production.value

    params["videoProduction"] = json_video_production

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/o/{organization_id}/seasons",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[SeasonListByOrganizationResponseDefault, SeasonListByOrganizationSeasonsResponse]:
    if response.status_code == 200:
        response_200 = SeasonListByOrganizationSeasonsResponse.from_dict(response.json())

        return response_200

    response_default = SeasonListByOrganizationResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[SeasonListByOrganizationResponseDefault, SeasonListByOrganizationSeasonsResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    age_group: Union[Unset, SeasonListByOrganizationAgeGroup] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    discipline: Union[Unset, SeasonListByOrganizationDiscipline] = UNSET,
    end_date: Union[Unset, datetime.date] = UNSET,
    event_type: Union[Unset, SeasonListByOrganizationEventType] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    gender: Union[Unset, SeasonListByOrganizationGender] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    name_latin_contains: Union[Unset, str] = UNSET,
    name_local_contains: Union[Unset, str] = UNSET,
    offset: Union[Unset, int] = UNSET,
    representation: Union[Unset, SeasonListByOrganizationRepresentation] = UNSET,
    season_type: Union[Unset, SeasonListByOrganizationSeasonType] = UNSET,
    sort_by: Union[Unset, str] = UNSET,
    standard: Union[Unset, SeasonListByOrganizationStandard] = UNSET,
    start_date: Union[Unset, datetime.date] = UNSET,
    status: Union[Unset, SeasonListByOrganizationStatus] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    video_production: Union[Unset, SeasonListByOrganizationVideoProduction] = UNSET,
) -> Response[Union[SeasonListByOrganizationResponseDefault, SeasonListByOrganizationSeasonsResponse]]:
    """Get a list of seasons for an organization

     Return a list of seasons in an organization.

    Args:
        organization_id (str):  Example: b1a23.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        age_group (Union[Unset, SeasonListByOrganizationAgeGroup]):  Example: SENIOR.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        discipline (Union[Unset, SeasonListByOrganizationDiscipline]):  Example: INDOOR.
        end_date (Union[Unset, datetime.date]):  Example: 2018-08-16.
        event_type (Union[Unset, SeasonListByOrganizationEventType]):  Example: FIXTURE.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        gender (Union[Unset, SeasonListByOrganizationGender]):  Example: MALE.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        name_latin_contains (Union[Unset, str]):  Example: Dav and nameLatin='David Johnson'.
        name_local_contains (Union[Unset, str]):  Example: Dav and nameLocal='David Johnson'.
        offset (Union[Unset, int]):  Example: 10.
        representation (Union[Unset, SeasonListByOrganizationRepresentation]):  Example: CLUB.
        season_type (Union[Unset, SeasonListByOrganizationSeasonType]):  Example: SEASON.
        sort_by (Union[Unset, str]):  Example: -nameLocal.
        standard (Union[Unset, SeasonListByOrganizationStandard]):  Example: ELITE.
        start_date (Union[Unset, datetime.date]):  Example: 2018-08-16.
        status (Union[Unset, SeasonListByOrganizationStatus]):  Example: ACTIVE.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        video_production (Union[Unset, SeasonListByOrganizationVideoProduction]):  Example:
            NONE,AUTOMATED.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[SeasonListByOrganizationResponseDefault, SeasonListByOrganizationSeasonsResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        added=added,
        age_group=age_group,
        competition_id=competition_id,
        discipline=discipline,
        end_date=end_date,
        event_type=event_type,
        external=external,
        fields=fields,
        gender=gender,
        hide_null=hide_null,
        include=include,
        limit=limit,
        name_latin_contains=name_latin_contains,
        name_local_contains=name_local_contains,
        offset=offset,
        representation=representation,
        season_type=season_type,
        sort_by=sort_by,
        standard=standard,
        start_date=start_date,
        status=status,
        updated=updated,
        video_production=video_production,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    age_group: Union[Unset, SeasonListByOrganizationAgeGroup] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    discipline: Union[Unset, SeasonListByOrganizationDiscipline] = UNSET,
    end_date: Union[Unset, datetime.date] = UNSET,
    event_type: Union[Unset, SeasonListByOrganizationEventType] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    gender: Union[Unset, SeasonListByOrganizationGender] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    name_latin_contains: Union[Unset, str] = UNSET,
    name_local_contains: Union[Unset, str] = UNSET,
    offset: Union[Unset, int] = UNSET,
    representation: Union[Unset, SeasonListByOrganizationRepresentation] = UNSET,
    season_type: Union[Unset, SeasonListByOrganizationSeasonType] = UNSET,
    sort_by: Union[Unset, str] = UNSET,
    standard: Union[Unset, SeasonListByOrganizationStandard] = UNSET,
    start_date: Union[Unset, datetime.date] = UNSET,
    status: Union[Unset, SeasonListByOrganizationStatus] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    video_production: Union[Unset, SeasonListByOrganizationVideoProduction] = UNSET,
) -> Optional[Union[SeasonListByOrganizationResponseDefault, SeasonListByOrganizationSeasonsResponse]]:
    """Get a list of seasons for an organization

     Return a list of seasons in an organization.

    Args:
        organization_id (str):  Example: b1a23.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        age_group (Union[Unset, SeasonListByOrganizationAgeGroup]):  Example: SENIOR.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        discipline (Union[Unset, SeasonListByOrganizationDiscipline]):  Example: INDOOR.
        end_date (Union[Unset, datetime.date]):  Example: 2018-08-16.
        event_type (Union[Unset, SeasonListByOrganizationEventType]):  Example: FIXTURE.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        gender (Union[Unset, SeasonListByOrganizationGender]):  Example: MALE.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        name_latin_contains (Union[Unset, str]):  Example: Dav and nameLatin='David Johnson'.
        name_local_contains (Union[Unset, str]):  Example: Dav and nameLocal='David Johnson'.
        offset (Union[Unset, int]):  Example: 10.
        representation (Union[Unset, SeasonListByOrganizationRepresentation]):  Example: CLUB.
        season_type (Union[Unset, SeasonListByOrganizationSeasonType]):  Example: SEASON.
        sort_by (Union[Unset, str]):  Example: -nameLocal.
        standard (Union[Unset, SeasonListByOrganizationStandard]):  Example: ELITE.
        start_date (Union[Unset, datetime.date]):  Example: 2018-08-16.
        status (Union[Unset, SeasonListByOrganizationStatus]):  Example: ACTIVE.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        video_production (Union[Unset, SeasonListByOrganizationVideoProduction]):  Example:
            NONE,AUTOMATED.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[SeasonListByOrganizationResponseDefault, SeasonListByOrganizationSeasonsResponse]
    """

    return sync_detailed(
        organization_id=organization_id,
        client=client,
        added=added,
        age_group=age_group,
        competition_id=competition_id,
        discipline=discipline,
        end_date=end_date,
        event_type=event_type,
        external=external,
        fields=fields,
        gender=gender,
        hide_null=hide_null,
        include=include,
        limit=limit,
        name_latin_contains=name_latin_contains,
        name_local_contains=name_local_contains,
        offset=offset,
        representation=representation,
        season_type=season_type,
        sort_by=sort_by,
        standard=standard,
        start_date=start_date,
        status=status,
        updated=updated,
        video_production=video_production,
    ).parsed


async def asyncio_detailed(
    organization_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    age_group: Union[Unset, SeasonListByOrganizationAgeGroup] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    discipline: Union[Unset, SeasonListByOrganizationDiscipline] = UNSET,
    end_date: Union[Unset, datetime.date] = UNSET,
    event_type: Union[Unset, SeasonListByOrganizationEventType] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    gender: Union[Unset, SeasonListByOrganizationGender] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    name_latin_contains: Union[Unset, str] = UNSET,
    name_local_contains: Union[Unset, str] = UNSET,
    offset: Union[Unset, int] = UNSET,
    representation: Union[Unset, SeasonListByOrganizationRepresentation] = UNSET,
    season_type: Union[Unset, SeasonListByOrganizationSeasonType] = UNSET,
    sort_by: Union[Unset, str] = UNSET,
    standard: Union[Unset, SeasonListByOrganizationStandard] = UNSET,
    start_date: Union[Unset, datetime.date] = UNSET,
    status: Union[Unset, SeasonListByOrganizationStatus] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    video_production: Union[Unset, SeasonListByOrganizationVideoProduction] = UNSET,
) -> Response[Union[SeasonListByOrganizationResponseDefault, SeasonListByOrganizationSeasonsResponse]]:
    """Get a list of seasons for an organization

     Return a list of seasons in an organization.

    Args:
        organization_id (str):  Example: b1a23.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        age_group (Union[Unset, SeasonListByOrganizationAgeGroup]):  Example: SENIOR.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        discipline (Union[Unset, SeasonListByOrganizationDiscipline]):  Example: INDOOR.
        end_date (Union[Unset, datetime.date]):  Example: 2018-08-16.
        event_type (Union[Unset, SeasonListByOrganizationEventType]):  Example: FIXTURE.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        gender (Union[Unset, SeasonListByOrganizationGender]):  Example: MALE.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        name_latin_contains (Union[Unset, str]):  Example: Dav and nameLatin='David Johnson'.
        name_local_contains (Union[Unset, str]):  Example: Dav and nameLocal='David Johnson'.
        offset (Union[Unset, int]):  Example: 10.
        representation (Union[Unset, SeasonListByOrganizationRepresentation]):  Example: CLUB.
        season_type (Union[Unset, SeasonListByOrganizationSeasonType]):  Example: SEASON.
        sort_by (Union[Unset, str]):  Example: -nameLocal.
        standard (Union[Unset, SeasonListByOrganizationStandard]):  Example: ELITE.
        start_date (Union[Unset, datetime.date]):  Example: 2018-08-16.
        status (Union[Unset, SeasonListByOrganizationStatus]):  Example: ACTIVE.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        video_production (Union[Unset, SeasonListByOrganizationVideoProduction]):  Example:
            NONE,AUTOMATED.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[SeasonListByOrganizationResponseDefault, SeasonListByOrganizationSeasonsResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        added=added,
        age_group=age_group,
        competition_id=competition_id,
        discipline=discipline,
        end_date=end_date,
        event_type=event_type,
        external=external,
        fields=fields,
        gender=gender,
        hide_null=hide_null,
        include=include,
        limit=limit,
        name_latin_contains=name_latin_contains,
        name_local_contains=name_local_contains,
        offset=offset,
        representation=representation,
        season_type=season_type,
        sort_by=sort_by,
        standard=standard,
        start_date=start_date,
        status=status,
        updated=updated,
        video_production=video_production,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    age_group: Union[Unset, SeasonListByOrganizationAgeGroup] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    discipline: Union[Unset, SeasonListByOrganizationDiscipline] = UNSET,
    end_date: Union[Unset, datetime.date] = UNSET,
    event_type: Union[Unset, SeasonListByOrganizationEventType] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    gender: Union[Unset, SeasonListByOrganizationGender] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    name_latin_contains: Union[Unset, str] = UNSET,
    name_local_contains: Union[Unset, str] = UNSET,
    offset: Union[Unset, int] = UNSET,
    representation: Union[Unset, SeasonListByOrganizationRepresentation] = UNSET,
    season_type: Union[Unset, SeasonListByOrganizationSeasonType] = UNSET,
    sort_by: Union[Unset, str] = UNSET,
    standard: Union[Unset, SeasonListByOrganizationStandard] = UNSET,
    start_date: Union[Unset, datetime.date] = UNSET,
    status: Union[Unset, SeasonListByOrganizationStatus] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    video_production: Union[Unset, SeasonListByOrganizationVideoProduction] = UNSET,
) -> Optional[Union[SeasonListByOrganizationResponseDefault, SeasonListByOrganizationSeasonsResponse]]:
    """Get a list of seasons for an organization

     Return a list of seasons in an organization.

    Args:
        organization_id (str):  Example: b1a23.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        age_group (Union[Unset, SeasonListByOrganizationAgeGroup]):  Example: SENIOR.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        discipline (Union[Unset, SeasonListByOrganizationDiscipline]):  Example: INDOOR.
        end_date (Union[Unset, datetime.date]):  Example: 2018-08-16.
        event_type (Union[Unset, SeasonListByOrganizationEventType]):  Example: FIXTURE.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        gender (Union[Unset, SeasonListByOrganizationGender]):  Example: MALE.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        name_latin_contains (Union[Unset, str]):  Example: Dav and nameLatin='David Johnson'.
        name_local_contains (Union[Unset, str]):  Example: Dav and nameLocal='David Johnson'.
        offset (Union[Unset, int]):  Example: 10.
        representation (Union[Unset, SeasonListByOrganizationRepresentation]):  Example: CLUB.
        season_type (Union[Unset, SeasonListByOrganizationSeasonType]):  Example: SEASON.
        sort_by (Union[Unset, str]):  Example: -nameLocal.
        standard (Union[Unset, SeasonListByOrganizationStandard]):  Example: ELITE.
        start_date (Union[Unset, datetime.date]):  Example: 2018-08-16.
        status (Union[Unset, SeasonListByOrganizationStatus]):  Example: ACTIVE.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        video_production (Union[Unset, SeasonListByOrganizationVideoProduction]):  Example:
            NONE,AUTOMATED.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[SeasonListByOrganizationResponseDefault, SeasonListByOrganizationSeasonsResponse]
    """

    return (
        await asyncio_detailed(
            organization_id=organization_id,
            client=client,
            added=added,
            age_group=age_group,
            competition_id=competition_id,
            discipline=discipline,
            end_date=end_date,
            event_type=event_type,
            external=external,
            fields=fields,
            gender=gender,
            hide_null=hide_null,
            include=include,
            limit=limit,
            name_latin_contains=name_latin_contains,
            name_local_contains=name_local_contains,
            offset=offset,
            representation=representation,
            season_type=season_type,
            sort_by=sort_by,
            standard=standard,
            start_date=start_date,
            status=status,
            updated=updated,
            video_production=video_production,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="MatchModelEnvironmentalDetails")


@_attrs_define
class MatchModelEnvironmentalDetails:
    """Details about the environment during the fixture

    Attributes:
        surface_condition (Union[Unset, str]): Condition of surface
    """

    surface_condition: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        surface_condition = self.surface_condition

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if surface_condition is not UNSET:
            field_dict["surfaceCondition"] = surface_condition

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        surface_condition = d.pop("surfaceCondition", UNSET)

        match_model_environmental_details = cls(
            surface_condition=surface_condition,
        )

        return match_model_environmental_details



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.match_persons_model_result_status import MatchPersonsModelResultStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.match_persons_model_entity_group import MatchPersonsModelEntityGroup
    from ..models.match_persons_model_fixture import MatchPersonsModelFixture
    from ..models.match_persons_model_organization import MatchPersonsModelOrganization
    from ..models.match_persons_model_person import MatchPersonsModelPerson
    from ..models.match_persons_model_uniform import MatchPersonsModelUniform


T = TypeVar("T", bound="MatchPersonsModel")


@_attrs_define
class MatchPersonsModel:
    """
    Attributes:
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, MatchPersonsModelFixture]): The match
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, MatchPersonsModelPerson]): The person information
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, MatchPersonsModelOrganization]): The organization that this match persons belongs to
        entity_group_id (Union[None, UUID, Unset]): The club that this team belongs to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_group (Union[Unset, MatchPersonsModelEntityGroup]): The club that this team belongs to
        is_home (Union[Unset, bool]): Is competitor the home person ? Example: True.
        draw (Union[Unset, bool]): Result for this competitor was a draw ? Example: True.
        result_status (Union[Unset, MatchPersonsModelResultStatus]): Result status
            >- `CONFIRMED` Confirmed
            >- `DID_NOT_FINISH` Did Not Finish
            >- `DID_NOT_START` Did Not Start
            >- `DISQUALIFIED` Disqualified
            >- `FORFEITED` Forfeited
            >- `IN_PROGRESS` In Progress
            >- `SCHEDULED` Scheduled
            >- `WITHDRAWN` Withdrawn
            >- `WON_BY_FORFEIT` Won By Forfeit
             Example: CONFIRMED.
        result_place (Union[None, Unset, int]): Result placing (1=Won, 2=Lost) Example: 1.
        result_secondary_score_place (Union[None, Unset, int]): Result placing (1=Won, 2=Lost) of the Shoot Out Example:
            1.
        starting_number (Union[None, Unset, int]): Starting number Example: 1.
        score (Union[None, Unset, str]): Score for competitor in match Example: 98.
        secondary_score (Union[None, Unset, str]): Secondary score Example: 3v3.
        is_neutral_venue (Union[Unset, bool]): Competitor is playing at a neutral venue ? Example: True.
        include_in_representation (Union[Unset, bool]): Include this match in represented statistics? Default: True.
            Example: True.
        uniform_id (Union[None, UUID, Unset]): The unique identifier of the uniform Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        uniform (Union[Unset, MatchPersonsModelUniform]): The Uniform information
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "MatchPersonsModelFixture"] = UNSET
    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "MatchPersonsModelPerson"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "MatchPersonsModelOrganization"] = UNSET
    entity_group_id: Union[None, UUID, Unset] = UNSET
    entity_group: Union[Unset, "MatchPersonsModelEntityGroup"] = UNSET
    is_home: Union[Unset, bool] = UNSET
    draw: Union[Unset, bool] = UNSET
    result_status: Union[Unset, MatchPersonsModelResultStatus] = UNSET
    result_place: Union[None, Unset, int] = UNSET
    result_secondary_score_place: Union[None, Unset, int] = UNSET
    starting_number: Union[None, Unset, int] = UNSET
    score: Union[None, Unset, str] = UNSET
    secondary_score: Union[None, Unset, str] = UNSET
    is_neutral_venue: Union[Unset, bool] = UNSET
    include_in_representation: Union[Unset, bool] = True
    uniform_id: Union[None, UUID, Unset] = UNSET
    uniform: Union[Unset, "MatchPersonsModelUniform"] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        entity_group_id: Union[None, Unset, str]
        if isinstance(self.entity_group_id, Unset):
            entity_group_id = UNSET
        elif isinstance(self.entity_group_id, UUID):
            entity_group_id = str(self.entity_group_id)
        else:
            entity_group_id = self.entity_group_id

        entity_group: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity_group, Unset):
            entity_group = self.entity_group.to_dict()

        is_home = self.is_home

        draw = self.draw

        result_status: Union[Unset, str] = UNSET
        if not isinstance(self.result_status, Unset):
            result_status = self.result_status.value

        result_place: Union[None, Unset, int]
        if isinstance(self.result_place, Unset):
            result_place = UNSET
        else:
            result_place = self.result_place

        result_secondary_score_place: Union[None, Unset, int]
        if isinstance(self.result_secondary_score_place, Unset):
            result_secondary_score_place = UNSET
        else:
            result_secondary_score_place = self.result_secondary_score_place

        starting_number: Union[None, Unset, int]
        if isinstance(self.starting_number, Unset):
            starting_number = UNSET
        else:
            starting_number = self.starting_number

        score: Union[None, Unset, str]
        if isinstance(self.score, Unset):
            score = UNSET
        else:
            score = self.score

        secondary_score: Union[None, Unset, str]
        if isinstance(self.secondary_score, Unset):
            secondary_score = UNSET
        else:
            secondary_score = self.secondary_score

        is_neutral_venue = self.is_neutral_venue

        include_in_representation = self.include_in_representation

        uniform_id: Union[None, Unset, str]
        if isinstance(self.uniform_id, Unset):
            uniform_id = UNSET
        elif isinstance(self.uniform_id, UUID):
            uniform_id = str(self.uniform_id)
        else:
            uniform_id = self.uniform_id

        uniform: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.uniform, Unset):
            uniform = self.uniform.to_dict()

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if entity_group_id is not UNSET:
            field_dict["entityGroupId"] = entity_group_id
        if entity_group is not UNSET:
            field_dict["entityGroup"] = entity_group
        if is_home is not UNSET:
            field_dict["isHome"] = is_home
        if draw is not UNSET:
            field_dict["draw"] = draw
        if result_status is not UNSET:
            field_dict["resultStatus"] = result_status
        if result_place is not UNSET:
            field_dict["resultPlace"] = result_place
        if result_secondary_score_place is not UNSET:
            field_dict["resultSecondaryScorePlace"] = result_secondary_score_place
        if starting_number is not UNSET:
            field_dict["startingNumber"] = starting_number
        if score is not UNSET:
            field_dict["score"] = score
        if secondary_score is not UNSET:
            field_dict["secondaryScore"] = secondary_score
        if is_neutral_venue is not UNSET:
            field_dict["isNeutralVenue"] = is_neutral_venue
        if include_in_representation is not UNSET:
            field_dict["includeInRepresentation"] = include_in_representation
        if uniform_id is not UNSET:
            field_dict["uniformId"] = uniform_id
        if uniform is not UNSET:
            field_dict["uniform"] = uniform
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.match_persons_model_entity_group import MatchPersonsModelEntityGroup
        from ..models.match_persons_model_fixture import MatchPersonsModelFixture
        from ..models.match_persons_model_organization import MatchPersonsModelOrganization
        from ..models.match_persons_model_person import MatchPersonsModelPerson
        from ..models.match_persons_model_uniform import MatchPersonsModelUniform

        d = dict(src_dict)
        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, MatchPersonsModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = MatchPersonsModelFixture.from_dict(_fixture)

        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, MatchPersonsModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = MatchPersonsModelPerson.from_dict(_person)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, MatchPersonsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = MatchPersonsModelOrganization.from_dict(_organization)

        def _parse_entity_group_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                entity_group_id_type_0 = UUID(data)

                return entity_group_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        entity_group_id = _parse_entity_group_id(d.pop("entityGroupId", UNSET))

        _entity_group = d.pop("entityGroup", UNSET)
        entity_group: Union[Unset, MatchPersonsModelEntityGroup]
        if isinstance(_entity_group, Unset):
            entity_group = UNSET
        else:
            entity_group = MatchPersonsModelEntityGroup.from_dict(_entity_group)

        is_home = d.pop("isHome", UNSET)

        draw = d.pop("draw", UNSET)

        _result_status = d.pop("resultStatus", UNSET)
        result_status: Union[Unset, MatchPersonsModelResultStatus]
        if isinstance(_result_status, Unset):
            result_status = UNSET
        else:
            result_status = MatchPersonsModelResultStatus(_result_status)

        def _parse_result_place(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        result_place = _parse_result_place(d.pop("resultPlace", UNSET))

        def _parse_result_secondary_score_place(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        result_secondary_score_place = _parse_result_secondary_score_place(d.pop("resultSecondaryScorePlace", UNSET))

        def _parse_starting_number(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        starting_number = _parse_starting_number(d.pop("startingNumber", UNSET))

        def _parse_score(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        score = _parse_score(d.pop("score", UNSET))

        def _parse_secondary_score(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        secondary_score = _parse_secondary_score(d.pop("secondaryScore", UNSET))

        is_neutral_venue = d.pop("isNeutralVenue", UNSET)

        include_in_representation = d.pop("includeInRepresentation", UNSET)

        def _parse_uniform_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                uniform_id_type_0 = UUID(data)

                return uniform_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        uniform_id = _parse_uniform_id(d.pop("uniformId", UNSET))

        _uniform = d.pop("uniform", UNSET)
        uniform: Union[Unset, MatchPersonsModelUniform]
        if isinstance(_uniform, Unset):
            uniform = UNSET
        else:
            uniform = MatchPersonsModelUniform.from_dict(_uniform)

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        match_persons_model = cls(
            fixture_id=fixture_id,
            fixture=fixture,
            person_id=person_id,
            person=person,
            organization_id=organization_id,
            organization=organization,
            entity_group_id=entity_group_id,
            entity_group=entity_group,
            is_home=is_home,
            draw=draw,
            result_status=result_status,
            result_place=result_place,
            result_secondary_score_place=result_secondary_score_place,
            starting_number=starting_number,
            score=score,
            secondary_score=secondary_score,
            is_neutral_venue=is_neutral_venue,
            include_in_representation=include_in_representation,
            uniform_id=uniform_id,
            uniform=uniform,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return match_persons_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.award_model_award import AwardModelAward
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.award_model_competition import AwardModelCompetition
    from ..models.award_model_entity import AwardModelEntity
    from ..models.award_model_entity_group import AwardModelEntityGroup
    from ..models.award_model_fixture import AwardModelFixture
    from ..models.award_model_organization import AwardModelOrganization
    from ..models.award_model_person import AwardModelPerson
    from ..models.award_model_season import AwardModelSeason


T = TypeVar("T", bound="AwardModel")


@_attrs_define
class AwardModel:
    """
    Attributes:
        award_id (Union[Unset, UUID]): The unique identifier of the award Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, AwardModelOrganization]): The organization that this ~award~ belongs to
        person_id (Union[Unset, UUID]): The person that this award is for Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, AwardModelPerson]): The person information
        entity_group_id (Union[Unset, UUID]): The club that this award is linked to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_group (Union[Unset, AwardModelEntityGroup]): The club that this team belongs to
        entity_id (Union[Unset, UUID]): The team that this award is linked to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, AwardModelEntity]): The team information
        competition_id (Union[Unset, UUID]): The competition that this award is linked to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        competition (Union[Unset, AwardModelCompetition]): The competition that this season belongs to
        season_id (Union[Unset, UUID]): The season that this award is linked to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, AwardModelSeason]): The season linked to this record
        fixture_id (Union[Unset, UUID]): The match that this award is linked to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, AwardModelFixture]): The match
        votes (Union[None, Unset, int]): Number of votes Example: 1.
        date_from (Union[None, Unset, datetime.date]): Date the award is from Example: 1978-08-24.
        date_to (Union[None, Unset, datetime.date]): Date the award is until Example: 1978-08-24.
        award (Union[Unset, AwardModelAward]): Award
            >- `ALL_TEAM` All first team
            >- `COACH` Coach Award
            >- `DEFENSIVE` Defensive Player
            >- `DEFENSIVE_TEAM` Defensive team
            >- `HALL` Hall of Fame
            >- `HONOUR` Honoured
            >- `MIP` Most Improved Player
            >- `MVP` Most Valuable Player
            >- `OTHER` Other
            >- `ROOKIE` Rookie
             Example: MVP.
        award_sub_type (Union[None, Unset, str]): Award sub type Example: 1st Team.
        notes (Union[None, Unset, str]): Award Notes
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    award_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "AwardModelOrganization"] = UNSET
    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "AwardModelPerson"] = UNSET
    entity_group_id: Union[Unset, UUID] = UNSET
    entity_group: Union[Unset, "AwardModelEntityGroup"] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "AwardModelEntity"] = UNSET
    competition_id: Union[Unset, UUID] = UNSET
    competition: Union[Unset, "AwardModelCompetition"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "AwardModelSeason"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "AwardModelFixture"] = UNSET
    votes: Union[None, Unset, int] = UNSET
    date_from: Union[None, Unset, datetime.date] = UNSET
    date_to: Union[None, Unset, datetime.date] = UNSET
    award: Union[Unset, AwardModelAward] = UNSET
    award_sub_type: Union[None, Unset, str] = UNSET
    notes: Union[None, Unset, str] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        award_id: Union[Unset, str] = UNSET
        if not isinstance(self.award_id, Unset):
            award_id = str(self.award_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        entity_group_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_group_id, Unset):
            entity_group_id = str(self.entity_group_id)

        entity_group: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity_group, Unset):
            entity_group = self.entity_group.to_dict()

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        competition_id: Union[Unset, str] = UNSET
        if not isinstance(self.competition_id, Unset):
            competition_id = str(self.competition_id)

        competition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.competition, Unset):
            competition = self.competition.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        votes: Union[None, Unset, int]
        if isinstance(self.votes, Unset):
            votes = UNSET
        else:
            votes = self.votes

        date_from: Union[None, Unset, str]
        if isinstance(self.date_from, Unset):
            date_from = UNSET
        elif isinstance(self.date_from, datetime.date):
            date_from = self.date_from.isoformat()
        else:
            date_from = self.date_from

        date_to: Union[None, Unset, str]
        if isinstance(self.date_to, Unset):
            date_to = UNSET
        elif isinstance(self.date_to, datetime.date):
            date_to = self.date_to.isoformat()
        else:
            date_to = self.date_to

        award: Union[Unset, str] = UNSET
        if not isinstance(self.award, Unset):
            award = self.award.value

        award_sub_type: Union[None, Unset, str]
        if isinstance(self.award_sub_type, Unset):
            award_sub_type = UNSET
        else:
            award_sub_type = self.award_sub_type

        notes: Union[None, Unset, str]
        if isinstance(self.notes, Unset):
            notes = UNSET
        else:
            notes = self.notes

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if award_id is not UNSET:
            field_dict["awardId"] = award_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if entity_group_id is not UNSET:
            field_dict["entityGroupId"] = entity_group_id
        if entity_group is not UNSET:
            field_dict["entityGroup"] = entity_group
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if competition_id is not UNSET:
            field_dict["competitionId"] = competition_id
        if competition is not UNSET:
            field_dict["competition"] = competition
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if votes is not UNSET:
            field_dict["votes"] = votes
        if date_from is not UNSET:
            field_dict["dateFrom"] = date_from
        if date_to is not UNSET:
            field_dict["dateTo"] = date_to
        if award is not UNSET:
            field_dict["award"] = award
        if award_sub_type is not UNSET:
            field_dict["awardSubType"] = award_sub_type
        if notes is not UNSET:
            field_dict["notes"] = notes
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.award_model_competition import AwardModelCompetition
        from ..models.award_model_entity import AwardModelEntity
        from ..models.award_model_entity_group import AwardModelEntityGroup
        from ..models.award_model_fixture import AwardModelFixture
        from ..models.award_model_organization import AwardModelOrganization
        from ..models.award_model_person import AwardModelPerson
        from ..models.award_model_season import AwardModelSeason

        d = dict(src_dict)
        _award_id = d.pop("awardId", UNSET)
        award_id: Union[Unset, UUID]
        if isinstance(_award_id, Unset):
            award_id = UNSET
        else:
            award_id = UUID(_award_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, AwardModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = AwardModelOrganization.from_dict(_organization)

        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, AwardModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = AwardModelPerson.from_dict(_person)

        _entity_group_id = d.pop("entityGroupId", UNSET)
        entity_group_id: Union[Unset, UUID]
        if isinstance(_entity_group_id, Unset):
            entity_group_id = UNSET
        else:
            entity_group_id = UUID(_entity_group_id)

        _entity_group = d.pop("entityGroup", UNSET)
        entity_group: Union[Unset, AwardModelEntityGroup]
        if isinstance(_entity_group, Unset):
            entity_group = UNSET
        else:
            entity_group = AwardModelEntityGroup.from_dict(_entity_group)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, AwardModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = AwardModelEntity.from_dict(_entity)

        _competition_id = d.pop("competitionId", UNSET)
        competition_id: Union[Unset, UUID]
        if isinstance(_competition_id, Unset):
            competition_id = UNSET
        else:
            competition_id = UUID(_competition_id)

        _competition = d.pop("competition", UNSET)
        competition: Union[Unset, AwardModelCompetition]
        if isinstance(_competition, Unset):
            competition = UNSET
        else:
            competition = AwardModelCompetition.from_dict(_competition)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, AwardModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = AwardModelSeason.from_dict(_season)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, AwardModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = AwardModelFixture.from_dict(_fixture)

        def _parse_votes(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        votes = _parse_votes(d.pop("votes", UNSET))

        def _parse_date_from(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_from_type_0 = isoparse(data).date()

                return date_from_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_from = _parse_date_from(d.pop("dateFrom", UNSET))

        def _parse_date_to(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_to_type_0 = isoparse(data).date()

                return date_to_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_to = _parse_date_to(d.pop("dateTo", UNSET))

        _award = d.pop("award", UNSET)
        award: Union[Unset, AwardModelAward]
        if isinstance(_award, Unset):
            award = UNSET
        else:
            award = AwardModelAward(_award)

        def _parse_award_sub_type(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        award_sub_type = _parse_award_sub_type(d.pop("awardSubType", UNSET))

        def _parse_notes(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        notes = _parse_notes(d.pop("notes", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        award_model = cls(
            award_id=award_id,
            organization_id=organization_id,
            organization=organization,
            person_id=person_id,
            person=person,
            entity_group_id=entity_group_id,
            entity_group=entity_group,
            entity_id=entity_id,
            entity=entity,
            competition_id=competition_id,
            competition=competition,
            season_id=season_id,
            season=season,
            fixture_id=fixture_id,
            fixture=fixture,
            votes=votes,
            date_from=date_from,
            date_to=date_to,
            award=award,
            award_sub_type=award_sub_type,
            notes=notes,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return award_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.pool_model_organization import PoolModelOrganization
    from ..models.pool_model_season import PoolModelSeason
    from ..models.pool_model_stage import PoolModelStage


T = TypeVar("T", bound="PoolModel")


@_attrs_define
class PoolModel:
    """
    Attributes:
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, PoolModelOrganization]): The organization that this pool belongs to
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, PoolModelSeason]): The season linked to this record
        pool_code (Union[Unset, str]): A unique code for the pool. (Unique for season) Example: P1.
        stage_code (Union[None, Unset, str]): A unique code for the stage. (Unique for season) Example: ST1.
        stage (Union[Unset, PoolModelStage]): The stage that is related to this record
        name_local (Union[None, Unset, str]): The name of the pool in the [local](#section/Introduction/Character-Sets-
            and-Names) language Example: Stage 1.
        abbreviation_local (Union[None, Unset, str]): An abbreviation/short name in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: S1.
        name_latin (Union[None, Unset, str]): The name of the pool in [latin](#section/Introduction/Character-Sets-and-
            Names) characters Example: Stage 1.
        abbreviation_latin (Union[None, Unset, str]): An abbreviation/short name in
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: S1.
        pool_order (Union[None, Unset, int]): User defined sort order of the ~pool~ Example: 1.
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "PoolModelOrganization"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "PoolModelSeason"] = UNSET
    pool_code: Union[Unset, str] = UNSET
    stage_code: Union[None, Unset, str] = UNSET
    stage: Union[Unset, "PoolModelStage"] = UNSET
    name_local: Union[None, Unset, str] = UNSET
    abbreviation_local: Union[None, Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    abbreviation_latin: Union[None, Unset, str] = UNSET
    pool_order: Union[None, Unset, int] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        pool_code = self.pool_code

        stage_code: Union[None, Unset, str]
        if isinstance(self.stage_code, Unset):
            stage_code = UNSET
        else:
            stage_code = self.stage_code

        stage: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.stage, Unset):
            stage = self.stage.to_dict()

        name_local: Union[None, Unset, str]
        if isinstance(self.name_local, Unset):
            name_local = UNSET
        else:
            name_local = self.name_local

        abbreviation_local: Union[None, Unset, str]
        if isinstance(self.abbreviation_local, Unset):
            abbreviation_local = UNSET
        else:
            abbreviation_local = self.abbreviation_local

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        abbreviation_latin: Union[None, Unset, str]
        if isinstance(self.abbreviation_latin, Unset):
            abbreviation_latin = UNSET
        else:
            abbreviation_latin = self.abbreviation_latin

        pool_order: Union[None, Unset, int]
        if isinstance(self.pool_order, Unset):
            pool_order = UNSET
        else:
            pool_order = self.pool_order

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if pool_code is not UNSET:
            field_dict["poolCode"] = pool_code
        if stage_code is not UNSET:
            field_dict["stageCode"] = stage_code
        if stage is not UNSET:
            field_dict["stage"] = stage
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if abbreviation_local is not UNSET:
            field_dict["abbreviationLocal"] = abbreviation_local
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if abbreviation_latin is not UNSET:
            field_dict["abbreviationLatin"] = abbreviation_latin
        if pool_order is not UNSET:
            field_dict["poolOrder"] = pool_order
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.pool_model_organization import PoolModelOrganization
        from ..models.pool_model_season import PoolModelSeason
        from ..models.pool_model_stage import PoolModelStage

        d = dict(src_dict)
        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, PoolModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = PoolModelOrganization.from_dict(_organization)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, PoolModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = PoolModelSeason.from_dict(_season)

        pool_code = d.pop("poolCode", UNSET)

        def _parse_stage_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        stage_code = _parse_stage_code(d.pop("stageCode", UNSET))

        _stage = d.pop("stage", UNSET)
        stage: Union[Unset, PoolModelStage]
        if isinstance(_stage, Unset):
            stage = UNSET
        else:
            stage = PoolModelStage.from_dict(_stage)

        def _parse_name_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_local = _parse_name_local(d.pop("nameLocal", UNSET))

        def _parse_abbreviation_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_local = _parse_abbreviation_local(d.pop("abbreviationLocal", UNSET))

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_abbreviation_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_latin = _parse_abbreviation_latin(d.pop("abbreviationLatin", UNSET))

        def _parse_pool_order(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        pool_order = _parse_pool_order(d.pop("poolOrder", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        pool_model = cls(
            organization_id=organization_id,
            organization=organization,
            season_id=season_id,
            season=season,
            pool_code=pool_code,
            stage_code=stage_code,
            stage=stage,
            name_local=name_local,
            abbreviation_local=abbreviation_local,
            name_latin=name_latin,
            abbreviation_latin=abbreviation_latin,
            pool_order=pool_order,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return pool_model



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.season_standings_stages_pools_model_organization import SeasonStandingsStagesPoolsModelOrganization
    from ..models.season_standings_stages_pools_model_pool import SeasonStandingsStagesPoolsModelPool
    from ..models.season_standings_stages_pools_model_season import SeasonStandingsStagesPoolsModelSeason
    from ..models.season_standings_stages_pools_model_stage import SeasonStandingsStagesPoolsModelStage


T = TypeVar("T", bound="SeasonStandingsStagesPoolsModel")


@_attrs_define
class SeasonStandingsStagesPoolsModel:
    """
    Attributes:
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SeasonStandingsStagesPoolsModelSeason]): The season linked to this record
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SeasonStandingsStagesPoolsModelOrganization]): The organization that this season
            standings stages pools belongs to
        stage_code (Union[None, Unset, str]): A unique code for the stage. (Unique for season) Example: ST1.
        stage (Union[Unset, SeasonStandingsStagesPoolsModelStage]): The stage that is related to this record
        pool_code (Union[Unset, str]): A unique code for the pool. (Unique for season) Example: P1.
        pool (Union[Unset, SeasonStandingsStagesPoolsModelPool]): The pool that is related to this record
    """

    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SeasonStandingsStagesPoolsModelSeason"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SeasonStandingsStagesPoolsModelOrganization"] = UNSET
    stage_code: Union[None, Unset, str] = UNSET
    stage: Union[Unset, "SeasonStandingsStagesPoolsModelStage"] = UNSET
    pool_code: Union[Unset, str] = UNSET
    pool: Union[Unset, "SeasonStandingsStagesPoolsModelPool"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        stage_code: Union[None, Unset, str]
        if isinstance(self.stage_code, Unset):
            stage_code = UNSET
        else:
            stage_code = self.stage_code

        stage: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.stage, Unset):
            stage = self.stage.to_dict()

        pool_code = self.pool_code

        pool: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pool, Unset):
            pool = self.pool.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if stage_code is not UNSET:
            field_dict["stageCode"] = stage_code
        if stage is not UNSET:
            field_dict["stage"] = stage
        if pool_code is not UNSET:
            field_dict["poolCode"] = pool_code
        if pool is not UNSET:
            field_dict["pool"] = pool

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.season_standings_stages_pools_model_organization import (
            SeasonStandingsStagesPoolsModelOrganization,
        )
        from ..models.season_standings_stages_pools_model_pool import SeasonStandingsStagesPoolsModelPool
        from ..models.season_standings_stages_pools_model_season import SeasonStandingsStagesPoolsModelSeason
        from ..models.season_standings_stages_pools_model_stage import SeasonStandingsStagesPoolsModelStage

        d = dict(src_dict)
        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SeasonStandingsStagesPoolsModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SeasonStandingsStagesPoolsModelSeason.from_dict(_season)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SeasonStandingsStagesPoolsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SeasonStandingsStagesPoolsModelOrganization.from_dict(_organization)

        def _parse_stage_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        stage_code = _parse_stage_code(d.pop("stageCode", UNSET))

        _stage = d.pop("stage", UNSET)
        stage: Union[Unset, SeasonStandingsStagesPoolsModelStage]
        if isinstance(_stage, Unset):
            stage = UNSET
        else:
            stage = SeasonStandingsStagesPoolsModelStage.from_dict(_stage)

        pool_code = d.pop("poolCode", UNSET)

        _pool = d.pop("pool", UNSET)
        pool: Union[Unset, SeasonStandingsStagesPoolsModelPool]
        if isinstance(_pool, Unset):
            pool = UNSET
        else:
            pool = SeasonStandingsStagesPoolsModelPool.from_dict(_pool)

        season_standings_stages_pools_model = cls(
            season_id=season_id,
            season=season,
            organization_id=organization_id,
            organization=organization,
            stage_code=stage_code,
            stage=stage,
            pool_code=pool_code,
            pool=pool,
        )

        return season_standings_stages_pools_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.series_model_series_type import SeriesModelSeriesType
from ..models.series_model_status import SeriesModelStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.series_model_conference import SeriesModelConference
    from ..models.series_model_division import SeriesModelDivision
    from ..models.series_model_organization import SeriesModelOrganization
    from ..models.series_model_pool import SeriesModelPool
    from ..models.series_model_season import SeriesModelSeason
    from ..models.series_model_season_series_competitor import SeriesModelSeasonSeriesCompetitor
    from ..models.series_model_stage import SeriesModelStage


T = TypeVar("T", bound="SeriesModel")


@_attrs_define
class SeriesModel:
    """
    Attributes:
        series_code (Union[Unset, str]): A unique code for the season series. (Unique for season) Example: ST1.
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SeriesModelSeason]): The season linked to this record
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SeriesModelOrganization]): The organization that this series belongs to
        conference_id (Union[None, UUID, Unset]): The unique identifier of the conference Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        conference (Union[Unset, SeriesModelConference]): The conference information
        division_id (Union[None, UUID, Unset]): The unique identifier of the division Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        division (Union[Unset, SeriesModelDivision]): The division information
        name_local (Union[Unset, str]): The name of the series in the [local](#section/Introduction/Character-Sets-and-
            Names) language Example: Test name local.
        abbreviation_local (Union[None, Unset, str]): An abbreviation/short name in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: NFA.
        name_latin (Union[None, Unset, str]): The name of the series in [latin](#section/Introduction/Character-Sets-
            and-Names) characters Example: Test name latin .
        abbreviation_latin (Union[None, Unset, str]): An abbreviation/short name in
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: NFA.
        status (Union[Unset, SeriesModelStatus]): Status
            >- `ACTIVE` Active
            >- `COMPLETE` Complete
            >- `NOT_STARTED` Not Started
             Example: COMPLETE.
        series_type (Union[Unset, SeriesModelSeriesType]): The type of series
            >- `BEST_OF` Best of
            >- `HOME_AND_AWAY` Home and Away
            >- `KNOCKOUT` Knockout
             Example: BEST_OF.
        auto_calculated (Union[Unset, bool]): Is the winner auto calculated? Example: True.
        best_of (Union[None, Unset, int]): Best of number Example: 1.
        series_number (Union[None, Unset, int]): User defined series number Example: 1.
        max_fixtures_number (Union[None, Unset, int]): The maximum number of games within a playoff series Example: 1.
        winner (Union[None, UUID, Unset]): The unique identifier of the winner, person or entity Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        series_order (Union[None, Unset, int]): User defined sort order of the series Example: 1.
        stage_code (Union[None, Unset, str]): A unique code for the stage. (Unique for season) Example: ST1.
        stage (Union[Unset, SeriesModelStage]): The stage that is related to this record
        pool_code (Union[None, Unset, str]): A unique code for the pool. (Unique for season) Example: P1.
        pool (Union[Unset, SeriesModelPool]): The pool that is related to this record
        start_date (Union[None, Unset, datetime.date]): Series start date Example: 2016-09-08.
        end_date (Union[None, Unset, datetime.date]): Series end date Example: 2016-09-08.
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        competitors (Union[None, Unset, list['SeriesModelSeasonSeriesCompetitor']]): Array of competitors in the series.
            A competitor may have a results and a ranking
    """

    series_code: Union[Unset, str] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SeriesModelSeason"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SeriesModelOrganization"] = UNSET
    conference_id: Union[None, UUID, Unset] = UNSET
    conference: Union[Unset, "SeriesModelConference"] = UNSET
    division_id: Union[None, UUID, Unset] = UNSET
    division: Union[Unset, "SeriesModelDivision"] = UNSET
    name_local: Union[Unset, str] = UNSET
    abbreviation_local: Union[None, Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    abbreviation_latin: Union[None, Unset, str] = UNSET
    status: Union[Unset, SeriesModelStatus] = UNSET
    series_type: Union[Unset, SeriesModelSeriesType] = UNSET
    auto_calculated: Union[Unset, bool] = UNSET
    best_of: Union[None, Unset, int] = UNSET
    series_number: Union[None, Unset, int] = UNSET
    max_fixtures_number: Union[None, Unset, int] = UNSET
    winner: Union[None, UUID, Unset] = UNSET
    series_order: Union[None, Unset, int] = UNSET
    stage_code: Union[None, Unset, str] = UNSET
    stage: Union[Unset, "SeriesModelStage"] = UNSET
    pool_code: Union[None, Unset, str] = UNSET
    pool: Union[Unset, "SeriesModelPool"] = UNSET
    start_date: Union[None, Unset, datetime.date] = UNSET
    end_date: Union[None, Unset, datetime.date] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    competitors: Union[None, Unset, list["SeriesModelSeasonSeriesCompetitor"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        series_code = self.series_code

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        conference_id: Union[None, Unset, str]
        if isinstance(self.conference_id, Unset):
            conference_id = UNSET
        elif isinstance(self.conference_id, UUID):
            conference_id = str(self.conference_id)
        else:
            conference_id = self.conference_id

        conference: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.conference, Unset):
            conference = self.conference.to_dict()

        division_id: Union[None, Unset, str]
        if isinstance(self.division_id, Unset):
            division_id = UNSET
        elif isinstance(self.division_id, UUID):
            division_id = str(self.division_id)
        else:
            division_id = self.division_id

        division: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.division, Unset):
            division = self.division.to_dict()

        name_local = self.name_local

        abbreviation_local: Union[None, Unset, str]
        if isinstance(self.abbreviation_local, Unset):
            abbreviation_local = UNSET
        else:
            abbreviation_local = self.abbreviation_local

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        abbreviation_latin: Union[None, Unset, str]
        if isinstance(self.abbreviation_latin, Unset):
            abbreviation_latin = UNSET
        else:
            abbreviation_latin = self.abbreviation_latin

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        series_type: Union[Unset, str] = UNSET
        if not isinstance(self.series_type, Unset):
            series_type = self.series_type.value

        auto_calculated = self.auto_calculated

        best_of: Union[None, Unset, int]
        if isinstance(self.best_of, Unset):
            best_of = UNSET
        else:
            best_of = self.best_of

        series_number: Union[None, Unset, int]
        if isinstance(self.series_number, Unset):
            series_number = UNSET
        else:
            series_number = self.series_number

        max_fixtures_number: Union[None, Unset, int]
        if isinstance(self.max_fixtures_number, Unset):
            max_fixtures_number = UNSET
        else:
            max_fixtures_number = self.max_fixtures_number

        winner: Union[None, Unset, str]
        if isinstance(self.winner, Unset):
            winner = UNSET
        elif isinstance(self.winner, UUID):
            winner = str(self.winner)
        else:
            winner = self.winner

        series_order: Union[None, Unset, int]
        if isinstance(self.series_order, Unset):
            series_order = UNSET
        else:
            series_order = self.series_order

        stage_code: Union[None, Unset, str]
        if isinstance(self.stage_code, Unset):
            stage_code = UNSET
        else:
            stage_code = self.stage_code

        stage: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.stage, Unset):
            stage = self.stage.to_dict()

        pool_code: Union[None, Unset, str]
        if isinstance(self.pool_code, Unset):
            pool_code = UNSET
        else:
            pool_code = self.pool_code

        pool: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pool, Unset):
            pool = self.pool.to_dict()

        start_date: Union[None, Unset, str]
        if isinstance(self.start_date, Unset):
            start_date = UNSET
        elif isinstance(self.start_date, datetime.date):
            start_date = self.start_date.isoformat()
        else:
            start_date = self.start_date

        end_date: Union[None, Unset, str]
        if isinstance(self.end_date, Unset):
            end_date = UNSET
        elif isinstance(self.end_date, datetime.date):
            end_date = self.end_date.isoformat()
        else:
            end_date = self.end_date

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        competitors: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.competitors, Unset):
            competitors = UNSET
        elif isinstance(self.competitors, list):
            competitors = []
            for competitors_type_0_item_data in self.competitors:
                competitors_type_0_item = competitors_type_0_item_data.to_dict()
                competitors.append(competitors_type_0_item)

        else:
            competitors = self.competitors

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if series_code is not UNSET:
            field_dict["seriesCode"] = series_code
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if conference_id is not UNSET:
            field_dict["conferenceId"] = conference_id
        if conference is not UNSET:
            field_dict["conference"] = conference
        if division_id is not UNSET:
            field_dict["divisionId"] = division_id
        if division is not UNSET:
            field_dict["division"] = division
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if abbreviation_local is not UNSET:
            field_dict["abbreviationLocal"] = abbreviation_local
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if abbreviation_latin is not UNSET:
            field_dict["abbreviationLatin"] = abbreviation_latin
        if status is not UNSET:
            field_dict["status"] = status
        if series_type is not UNSET:
            field_dict["seriesType"] = series_type
        if auto_calculated is not UNSET:
            field_dict["autoCalculated"] = auto_calculated
        if best_of is not UNSET:
            field_dict["bestOf"] = best_of
        if series_number is not UNSET:
            field_dict["seriesNumber"] = series_number
        if max_fixtures_number is not UNSET:
            field_dict["maxFixturesNumber"] = max_fixtures_number
        if winner is not UNSET:
            field_dict["winner"] = winner
        if series_order is not UNSET:
            field_dict["seriesOrder"] = series_order
        if stage_code is not UNSET:
            field_dict["stageCode"] = stage_code
        if stage is not UNSET:
            field_dict["stage"] = stage
        if pool_code is not UNSET:
            field_dict["poolCode"] = pool_code
        if pool is not UNSET:
            field_dict["pool"] = pool
        if start_date is not UNSET:
            field_dict["startDate"] = start_date
        if end_date is not UNSET:
            field_dict["endDate"] = end_date
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if competitors is not UNSET:
            field_dict["competitors"] = competitors

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.series_model_conference import SeriesModelConference
        from ..models.series_model_division import SeriesModelDivision
        from ..models.series_model_organization import SeriesModelOrganization
        from ..models.series_model_pool import SeriesModelPool
        from ..models.series_model_season import SeriesModelSeason
        from ..models.series_model_season_series_competitor import SeriesModelSeasonSeriesCompetitor
        from ..models.series_model_stage import SeriesModelStage

        d = dict(src_dict)
        series_code = d.pop("seriesCode", UNSET)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SeriesModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SeriesModelSeason.from_dict(_season)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SeriesModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SeriesModelOrganization.from_dict(_organization)

        def _parse_conference_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                conference_id_type_0 = UUID(data)

                return conference_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        conference_id = _parse_conference_id(d.pop("conferenceId", UNSET))

        _conference = d.pop("conference", UNSET)
        conference: Union[Unset, SeriesModelConference]
        if isinstance(_conference, Unset):
            conference = UNSET
        else:
            conference = SeriesModelConference.from_dict(_conference)

        def _parse_division_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                division_id_type_0 = UUID(data)

                return division_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        division_id = _parse_division_id(d.pop("divisionId", UNSET))

        _division = d.pop("division", UNSET)
        division: Union[Unset, SeriesModelDivision]
        if isinstance(_division, Unset):
            division = UNSET
        else:
            division = SeriesModelDivision.from_dict(_division)

        name_local = d.pop("nameLocal", UNSET)

        def _parse_abbreviation_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_local = _parse_abbreviation_local(d.pop("abbreviationLocal", UNSET))

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_abbreviation_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_latin = _parse_abbreviation_latin(d.pop("abbreviationLatin", UNSET))

        _status = d.pop("status", UNSET)
        status: Union[Unset, SeriesModelStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = SeriesModelStatus(_status)

        _series_type = d.pop("seriesType", UNSET)
        series_type: Union[Unset, SeriesModelSeriesType]
        if isinstance(_series_type, Unset):
            series_type = UNSET
        else:
            series_type = SeriesModelSeriesType(_series_type)

        auto_calculated = d.pop("autoCalculated", UNSET)

        def _parse_best_of(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        best_of = _parse_best_of(d.pop("bestOf", UNSET))

        def _parse_series_number(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        series_number = _parse_series_number(d.pop("seriesNumber", UNSET))

        def _parse_max_fixtures_number(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        max_fixtures_number = _parse_max_fixtures_number(d.pop("maxFixturesNumber", UNSET))

        def _parse_winner(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                winner_type_0 = UUID(data)

                return winner_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        winner = _parse_winner(d.pop("winner", UNSET))

        def _parse_series_order(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        series_order = _parse_series_order(d.pop("seriesOrder", UNSET))

        def _parse_stage_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        stage_code = _parse_stage_code(d.pop("stageCode", UNSET))

        _stage = d.pop("stage", UNSET)
        stage: Union[Unset, SeriesModelStage]
        if isinstance(_stage, Unset):
            stage = UNSET
        else:
            stage = SeriesModelStage.from_dict(_stage)

        def _parse_pool_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        pool_code = _parse_pool_code(d.pop("poolCode", UNSET))

        _pool = d.pop("pool", UNSET)
        pool: Union[Unset, SeriesModelPool]
        if isinstance(_pool, Unset):
            pool = UNSET
        else:
            pool = SeriesModelPool.from_dict(_pool)

        def _parse_start_date(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                start_date_type_0 = isoparse(data).date()

                return start_date_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        start_date = _parse_start_date(d.pop("startDate", UNSET))

        def _parse_end_date(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                end_date_type_0 = isoparse(data).date()

                return end_date_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        end_date = _parse_end_date(d.pop("endDate", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        def _parse_competitors(data: object) -> Union[None, Unset, list["SeriesModelSeasonSeriesCompetitor"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                competitors_type_0 = []
                _competitors_type_0 = data
                for competitors_type_0_item_data in _competitors_type_0:
                    competitors_type_0_item = SeriesModelSeasonSeriesCompetitor.from_dict(competitors_type_0_item_data)

                    competitors_type_0.append(competitors_type_0_item)

                return competitors_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["SeriesModelSeasonSeriesCompetitor"]], data)

        competitors = _parse_competitors(d.pop("competitors", UNSET))

        series_model = cls(
            series_code=series_code,
            season_id=season_id,
            season=season,
            organization_id=organization_id,
            organization=organization,
            conference_id=conference_id,
            conference=conference,
            division_id=division_id,
            division=division,
            name_local=name_local,
            abbreviation_local=abbreviation_local,
            name_latin=name_latin,
            abbreviation_latin=abbreviation_latin,
            status=status,
            series_type=series_type,
            auto_calculated=auto_calculated,
            best_of=best_of,
            series_number=series_number,
            max_fixtures_number=max_fixtures_number,
            winner=winner,
            series_order=series_order,
            stage_code=stage_code,
            stage=stage,
            pool_code=pool_code,
            pool=pool,
            start_date=start_date,
            end_date=end_date,
            external_id=external_id,
            updated=updated,
            added=added,
            competitors=competitors,
        )

        return series_model



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.person_model_person_additional_details_dominant_foot import PersonModelPersonAdditionalDetailsDominantFoot
from ..models.person_model_person_additional_details_dominant_hand import PersonModelPersonAdditionalDetailsDominantHand
from ..types import UNSET, Unset

T = TypeVar("T", bound="PersonModelPersonAdditionalDetails")


@_attrs_define
class PersonModelPersonAdditionalDetails:
    """Additional person detail fields

    Attributes:
        height (Union[None, Unset, float]): Height in cms
        height_imperial (Union[None, Unset, str]): Height in feet & inches
        weight (Union[None, Unset, float]): Weight in kgs
        weight_imperial (Union[None, Unset, float]): Weight in pounds
        dominant_hand (Union[Unset, PersonModelPersonAdditionalDetailsDominantHand]): Dominant hand
        dominant_foot (Union[Unset, PersonModelPersonAdditionalDetailsDominantFoot]): Dominant foot
        home_town (Union[None, Unset, str]): Hometown
        school (Union[None, Unset, str]): School
        school_class (Union[None, Unset, str]): School Class
        college (Union[None, Unset, str]): College
        college_class (Union[None, Unset, str]): College Class
        representation (Union[None, Unset, str]): Representation
        junior_association_league (Union[None, Unset, str]): Junior Association / League
    """

    height: Union[None, Unset, float] = UNSET
    height_imperial: Union[None, Unset, str] = UNSET
    weight: Union[None, Unset, float] = UNSET
    weight_imperial: Union[None, Unset, float] = UNSET
    dominant_hand: Union[Unset, PersonModelPersonAdditionalDetailsDominantHand] = UNSET
    dominant_foot: Union[Unset, PersonModelPersonAdditionalDetailsDominantFoot] = UNSET
    home_town: Union[None, Unset, str] = UNSET
    school: Union[None, Unset, str] = UNSET
    school_class: Union[None, Unset, str] = UNSET
    college: Union[None, Unset, str] = UNSET
    college_class: Union[None, Unset, str] = UNSET
    representation: Union[None, Unset, str] = UNSET
    junior_association_league: Union[None, Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        height: Union[None, Unset, float]
        if isinstance(self.height, Unset):
            height = UNSET
        else:
            height = self.height

        height_imperial: Union[None, Unset, str]
        if isinstance(self.height_imperial, Unset):
            height_imperial = UNSET
        else:
            height_imperial = self.height_imperial

        weight: Union[None, Unset, float]
        if isinstance(self.weight, Unset):
            weight = UNSET
        else:
            weight = self.weight

        weight_imperial: Union[None, Unset, float]
        if isinstance(self.weight_imperial, Unset):
            weight_imperial = UNSET
        else:
            weight_imperial = self.weight_imperial

        dominant_hand: Union[Unset, str] = UNSET
        if not isinstance(self.dominant_hand, Unset):
            dominant_hand = self.dominant_hand.value

        dominant_foot: Union[Unset, str] = UNSET
        if not isinstance(self.dominant_foot, Unset):
            dominant_foot = self.dominant_foot.value

        home_town: Union[None, Unset, str]
        if isinstance(self.home_town, Unset):
            home_town = UNSET
        else:
            home_town = self.home_town

        school: Union[None, Unset, str]
        if isinstance(self.school, Unset):
            school = UNSET
        else:
            school = self.school

        school_class: Union[None, Unset, str]
        if isinstance(self.school_class, Unset):
            school_class = UNSET
        else:
            school_class = self.school_class

        college: Union[None, Unset, str]
        if isinstance(self.college, Unset):
            college = UNSET
        else:
            college = self.college

        college_class: Union[None, Unset, str]
        if isinstance(self.college_class, Unset):
            college_class = UNSET
        else:
            college_class = self.college_class

        representation: Union[None, Unset, str]
        if isinstance(self.representation, Unset):
            representation = UNSET
        else:
            representation = self.representation

        junior_association_league: Union[None, Unset, str]
        if isinstance(self.junior_association_league, Unset):
            junior_association_league = UNSET
        else:
            junior_association_league = self.junior_association_league

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if height is not UNSET:
            field_dict["height"] = height
        if height_imperial is not UNSET:
            field_dict["heightImperial"] = height_imperial
        if weight is not UNSET:
            field_dict["weight"] = weight
        if weight_imperial is not UNSET:
            field_dict["weightImperial"] = weight_imperial
        if dominant_hand is not UNSET:
            field_dict["dominantHand"] = dominant_hand
        if dominant_foot is not UNSET:
            field_dict["dominantFoot"] = dominant_foot
        if home_town is not UNSET:
            field_dict["homeTown"] = home_town
        if school is not UNSET:
            field_dict["school"] = school
        if school_class is not UNSET:
            field_dict["schoolClass"] = school_class
        if college is not UNSET:
            field_dict["college"] = college
        if college_class is not UNSET:
            field_dict["collegeClass"] = college_class
        if representation is not UNSET:
            field_dict["representation"] = representation
        if junior_association_league is not UNSET:
            field_dict["juniorAssociationLeague"] = junior_association_league

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_height(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        height = _parse_height(d.pop("height", UNSET))

        def _parse_height_imperial(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        height_imperial = _parse_height_imperial(d.pop("heightImperial", UNSET))

        def _parse_weight(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        weight = _parse_weight(d.pop("weight", UNSET))

        def _parse_weight_imperial(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        weight_imperial = _parse_weight_imperial(d.pop("weightImperial", UNSET))

        _dominant_hand = d.pop("dominantHand", UNSET)
        dominant_hand: Union[Unset, PersonModelPersonAdditionalDetailsDominantHand]
        if isinstance(_dominant_hand, Unset):
            dominant_hand = UNSET
        else:
            dominant_hand = PersonModelPersonAdditionalDetailsDominantHand(_dominant_hand)

        _dominant_foot = d.pop("dominantFoot", UNSET)
        dominant_foot: Union[Unset, PersonModelPersonAdditionalDetailsDominantFoot]
        if isinstance(_dominant_foot, Unset):
            dominant_foot = UNSET
        else:
            dominant_foot = PersonModelPersonAdditionalDetailsDominantFoot(_dominant_foot)

        def _parse_home_town(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        home_town = _parse_home_town(d.pop("homeTown", UNSET))

        def _parse_school(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        school = _parse_school(d.pop("school", UNSET))

        def _parse_school_class(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        school_class = _parse_school_class(d.pop("schoolClass", UNSET))

        def _parse_college(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        college = _parse_college(d.pop("college", UNSET))

        def _parse_college_class(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        college_class = _parse_college_class(d.pop("collegeClass", UNSET))

        def _parse_representation(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        representation = _parse_representation(d.pop("representation", UNSET))

        def _parse_junior_association_league(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        junior_association_league = _parse_junior_association_league(d.pop("juniorAssociationLeague", UNSET))

        person_model_person_additional_details = cls(
            height=height,
            height_imperial=height_imperial,
            weight=weight,
            weight_imperial=weight_imperial,
            dominant_hand=dominant_hand,
            dominant_foot=dominant_foot,
            home_town=home_town,
            school=school,
            school_class=school_class,
            college=college,
            college_class=college_class,
            representation=representation,
            junior_association_league=junior_association_league,
        )

        return person_model_person_additional_details



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="TeamModelAdditionalNames")


@_attrs_define
class TeamModelAdditionalNames:
    """
    Attributes:
        name_short_local (Union[None, Unset, str]): The short name of the team in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: Armadillos.
        name_place_local (Union[None, Unset, str]): The name of the place associated with the team in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: Los Angeles.
        name_short_latin (Union[None, Unset, str]): The short name of the team using
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: Armadillos.
        name_place_latin (Union[None, Unset, str]): The name of the place associated with the team using
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: Los Angeles.
    """

    name_short_local: Union[None, Unset, str] = UNSET
    name_place_local: Union[None, Unset, str] = UNSET
    name_short_latin: Union[None, Unset, str] = UNSET
    name_place_latin: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        name_short_local: Union[None, Unset, str]
        if isinstance(self.name_short_local, Unset):
            name_short_local = UNSET
        else:
            name_short_local = self.name_short_local

        name_place_local: Union[None, Unset, str]
        if isinstance(self.name_place_local, Unset):
            name_place_local = UNSET
        else:
            name_place_local = self.name_place_local

        name_short_latin: Union[None, Unset, str]
        if isinstance(self.name_short_latin, Unset):
            name_short_latin = UNSET
        else:
            name_short_latin = self.name_short_latin

        name_place_latin: Union[None, Unset, str]
        if isinstance(self.name_place_latin, Unset):
            name_place_latin = UNSET
        else:
            name_place_latin = self.name_place_latin

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name_short_local is not UNSET:
            field_dict["nameShortLocal"] = name_short_local
        if name_place_local is not UNSET:
            field_dict["namePlaceLocal"] = name_place_local
        if name_short_latin is not UNSET:
            field_dict["nameShortLatin"] = name_short_latin
        if name_place_latin is not UNSET:
            field_dict["namePlaceLatin"] = name_place_latin

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_name_short_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_short_local = _parse_name_short_local(d.pop("nameShortLocal", UNSET))

        def _parse_name_place_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_place_local = _parse_name_place_local(d.pop("namePlaceLocal", UNSET))

        def _parse_name_short_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_short_latin = _parse_name_short_latin(d.pop("nameShortLatin", UNSET))

        def _parse_name_place_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_place_latin = _parse_name_place_latin(d.pop("namePlaceLatin", UNSET))

        team_model_additional_names = cls(
            name_short_local=name_short_local,
            name_place_local=name_place_local,
            name_short_latin=name_short_latin,
            name_place_latin=name_place_latin,
        )

        team_model_additional_names.additional_properties = d
        return team_model_additional_names

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.division_model_conference import DivisionModelConference
    from ..models.division_model_organization import DivisionModelOrganization
    from ..models.division_model_social_media import DivisionModelSocialMedia
    from ..models.images_model import ImagesModel


T = TypeVar("T", bound="DivisionModel")


@_attrs_define
class DivisionModel:
    """
    Attributes:
        division_id (Union[None, UUID, Unset]): The unique identifier of the division Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, DivisionModelOrganization]): The organization that this division belongs to
        conference_id (Union[None, UUID, Unset]): The unique identifier of the conference Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        conference (Union[Unset, DivisionModelConference]): The conference information
        abbreviation_local (Union[None, Unset, str]): An abbreviation/short name in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: NFA.
        name_local (Union[Unset, str]): The name of the division in the [local](#section/Introduction/Character-Sets-
            and-Names) language Example: Test name local.
        abbreviation_latin (Union[None, Unset, str]): An abbreviation/short name in
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: NFA.
        name_latin (Union[None, Unset, str]): The name of the division in [latin](#section/Introduction/Character-Sets-
            and-Names) characters Example: Test name latin .
        social (Union['DivisionModelSocialMedia', None, Unset]): Social Media contacts
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        images (Union[Unset, list['ImagesModel']]):
    """

    division_id: Union[None, UUID, Unset] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "DivisionModelOrganization"] = UNSET
    conference_id: Union[None, UUID, Unset] = UNSET
    conference: Union[Unset, "DivisionModelConference"] = UNSET
    abbreviation_local: Union[None, Unset, str] = UNSET
    name_local: Union[Unset, str] = UNSET
    abbreviation_latin: Union[None, Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    social: Union["DivisionModelSocialMedia", None, Unset] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    images: Union[Unset, list["ImagesModel"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.division_model_social_media import DivisionModelSocialMedia

        division_id: Union[None, Unset, str]
        if isinstance(self.division_id, Unset):
            division_id = UNSET
        elif isinstance(self.division_id, UUID):
            division_id = str(self.division_id)
        else:
            division_id = self.division_id

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        conference_id: Union[None, Unset, str]
        if isinstance(self.conference_id, Unset):
            conference_id = UNSET
        elif isinstance(self.conference_id, UUID):
            conference_id = str(self.conference_id)
        else:
            conference_id = self.conference_id

        conference: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.conference, Unset):
            conference = self.conference.to_dict()

        abbreviation_local: Union[None, Unset, str]
        if isinstance(self.abbreviation_local, Unset):
            abbreviation_local = UNSET
        else:
            abbreviation_local = self.abbreviation_local

        name_local = self.name_local

        abbreviation_latin: Union[None, Unset, str]
        if isinstance(self.abbreviation_latin, Unset):
            abbreviation_latin = UNSET
        else:
            abbreviation_latin = self.abbreviation_latin

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        social: Union[None, Unset, dict[str, Any]]
        if isinstance(self.social, Unset):
            social = UNSET
        elif isinstance(self.social, DivisionModelSocialMedia):
            social = self.social.to_dict()
        else:
            social = self.social

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        images: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.images, Unset):
            images = []
            for images_item_data in self.images:
                images_item = images_item_data.to_dict()
                images.append(images_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if division_id is not UNSET:
            field_dict["divisionId"] = division_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if conference_id is not UNSET:
            field_dict["conferenceId"] = conference_id
        if conference is not UNSET:
            field_dict["conference"] = conference
        if abbreviation_local is not UNSET:
            field_dict["abbreviationLocal"] = abbreviation_local
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if abbreviation_latin is not UNSET:
            field_dict["abbreviationLatin"] = abbreviation_latin
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if social is not UNSET:
            field_dict["social"] = social
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if images is not UNSET:
            field_dict["images"] = images

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.division_model_conference import DivisionModelConference
        from ..models.division_model_organization import DivisionModelOrganization
        from ..models.division_model_social_media import DivisionModelSocialMedia
        from ..models.images_model import ImagesModel

        d = dict(src_dict)

        def _parse_division_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                division_id_type_0 = UUID(data)

                return division_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        division_id = _parse_division_id(d.pop("divisionId", UNSET))

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, DivisionModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = DivisionModelOrganization.from_dict(_organization)

        def _parse_conference_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                conference_id_type_0 = UUID(data)

                return conference_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        conference_id = _parse_conference_id(d.pop("conferenceId", UNSET))

        _conference = d.pop("conference", UNSET)
        conference: Union[Unset, DivisionModelConference]
        if isinstance(_conference, Unset):
            conference = UNSET
        else:
            conference = DivisionModelConference.from_dict(_conference)

        def _parse_abbreviation_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_local = _parse_abbreviation_local(d.pop("abbreviationLocal", UNSET))

        name_local = d.pop("nameLocal", UNSET)

        def _parse_abbreviation_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_latin = _parse_abbreviation_latin(d.pop("abbreviationLatin", UNSET))

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_social(data: object) -> Union["DivisionModelSocialMedia", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                social_type_0 = DivisionModelSocialMedia.from_dict(data)

                return social_type_0
            except:  # noqa: E722
                pass
            return cast(Union["DivisionModelSocialMedia", None, Unset], data)

        social = _parse_social(d.pop("social", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        images = []
        _images = d.pop("images", UNSET)
        for images_item_data in _images or []:
            images_item = ImagesModel.from_dict(images_item_data)

            images.append(images_item)

        division_model = cls(
            division_id=division_id,
            organization_id=organization_id,
            organization=organization,
            conference_id=conference_id,
            conference=conference,
            abbreviation_local=abbreviation_local,
            name_local=name_local,
            abbreviation_latin=abbreviation_latin,
            name_latin=name_latin,
            social=social,
            external_id=external_id,
            updated=updated,
            added=added,
            images=images,
        )

        return division_model



from enum import Enum


class CompetitionListSeasonStatusSeasonVideoProduction(str, Enum):
    AUTOMATED = "AUTOMATED"
    MANUAL = "MANUAL"
    NONE = "NONE"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class VideoStreamInputsModelAudioAmbienceChannel(str, Enum):
    CHANNEL_BOTH = "CHANNEL_BOTH"
    CHANNEL_LEFT = "CHANNEL_LEFT"
    CHANNEL_RIGHT = "CHANNEL_RIGHT"
    NONE = "NONE"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="SeasonModelSocialMedia")


@_attrs_define
class SeasonModelSocialMedia:
    """Social Media contacts

    Attributes:
        website (Union[None, Unset, str]):  Example: http://www.example.com.
        facebook (Union[None, Unset, str]):  Example: https://www.facebook.com/example.
        twitter (Union[None, Unset, str]):  Example: https://www.twitter.com/example.
        wikipedia (Union[None, Unset, str]):  Example: https://en.wikipedia.org/wiki/example.
        instagram (Union[None, Unset, str]):  Example: https://www.instagram.com/example.
    """

    website: Union[None, Unset, str] = UNSET
    facebook: Union[None, Unset, str] = UNSET
    twitter: Union[None, Unset, str] = UNSET
    wikipedia: Union[None, Unset, str] = UNSET
    instagram: Union[None, Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        website: Union[None, Unset, str]
        if isinstance(self.website, Unset):
            website = UNSET
        else:
            website = self.website

        facebook: Union[None, Unset, str]
        if isinstance(self.facebook, Unset):
            facebook = UNSET
        else:
            facebook = self.facebook

        twitter: Union[None, Unset, str]
        if isinstance(self.twitter, Unset):
            twitter = UNSET
        else:
            twitter = self.twitter

        wikipedia: Union[None, Unset, str]
        if isinstance(self.wikipedia, Unset):
            wikipedia = UNSET
        else:
            wikipedia = self.wikipedia

        instagram: Union[None, Unset, str]
        if isinstance(self.instagram, Unset):
            instagram = UNSET
        else:
            instagram = self.instagram

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if website is not UNSET:
            field_dict["website"] = website
        if facebook is not UNSET:
            field_dict["facebook"] = facebook
        if twitter is not UNSET:
            field_dict["twitter"] = twitter
        if wikipedia is not UNSET:
            field_dict["wikipedia"] = wikipedia
        if instagram is not UNSET:
            field_dict["instagram"] = instagram

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_website(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        website = _parse_website(d.pop("website", UNSET))

        def _parse_facebook(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        facebook = _parse_facebook(d.pop("facebook", UNSET))

        def _parse_twitter(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        twitter = _parse_twitter(d.pop("twitter", UNSET))

        def _parse_wikipedia(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        wikipedia = _parse_wikipedia(d.pop("wikipedia", UNSET))

        def _parse_instagram(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        instagram = _parse_instagram(d.pop("instagram", UNSET))

        season_model_social_media = cls(
            website=website,
            facebook=facebook,
            twitter=twitter,
            wikipedia=wikipedia,
            instagram=instagram,
        )

        return season_model_social_media



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define

from ..models.career_person_representational_statistics_model_age_group import (
    CareerPersonRepresentationalStatisticsModelAgeGroup,
)
from ..models.career_person_representational_statistics_model_discipline_type_1 import (
    CareerPersonRepresentationalStatisticsModelDisciplineType1,
)
from ..models.career_person_representational_statistics_model_discipline_type_2_type_1 import (
    CareerPersonRepresentationalStatisticsModelDisciplineType2Type1,
)
from ..models.career_person_representational_statistics_model_discipline_type_3_type_1 import (
    CareerPersonRepresentationalStatisticsModelDisciplineType3Type1,
)
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.career_person_representational_statistics_model_organization import (
        CareerPersonRepresentationalStatisticsModelOrganization,
    )
    from ..models.career_person_representational_statistics_model_person import (
        CareerPersonRepresentationalStatisticsModelPerson,
    )
    from ..models.career_person_representational_statistics_model_statistics import (
        CareerPersonRepresentationalStatisticsModelStatistics,
    )


T = TypeVar("T", bound="CareerPersonRepresentationalStatisticsModel")


@_attrs_define
class CareerPersonRepresentationalStatisticsModel:
    """
    Attributes:
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, CareerPersonRepresentationalStatisticsModelPerson]): The person information
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, CareerPersonRepresentationalStatisticsModelOrganization]): The organization that this
            career person representational_statistics belongs to
        age_group (Union[Unset, CareerPersonRepresentationalStatisticsModelAgeGroup]): The age group of the season
            >- `JUNIOR` Junior
            >- `MASTERS` Masters
            >- `SENIOR` Senior
            >- `UNDER_15` Under 15
            >- `UNDER_16` Under 16
            >- `UNDER_17` Under 17
            >- `UNDER_18` Under 18
            >- `UNDER_19` Under 19
            >- `UNDER_20` Under 20
            >- `UNDER_21` Under 21
            >- `UNDER_22` Under 22
            >- `UNDER_23` Under 23
            >- `YOUTH` Youth
             Example: SENIOR.
        discipline (Union[CareerPersonRepresentationalStatisticsModelDisciplineType1,
            CareerPersonRepresentationalStatisticsModelDisciplineType2Type1,
            CareerPersonRepresentationalStatisticsModelDisciplineType3Type1, None, Unset]): match discipline
            >- None None
            >- `INDOOR` Indoor
            >- `OUTDOOR` Outdoor
             Example: INDOOR.
        representing (Union[None, Unset, str]): Who the person or team was representing Example: AUSTRALIA.
        statistics (Union[Unset, CareerPersonRepresentationalStatisticsModelStatistics]):
    """

    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "CareerPersonRepresentationalStatisticsModelPerson"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "CareerPersonRepresentationalStatisticsModelOrganization"] = UNSET
    age_group: Union[Unset, CareerPersonRepresentationalStatisticsModelAgeGroup] = UNSET
    discipline: Union[
        CareerPersonRepresentationalStatisticsModelDisciplineType1,
        CareerPersonRepresentationalStatisticsModelDisciplineType2Type1,
        CareerPersonRepresentationalStatisticsModelDisciplineType3Type1,
        None,
        Unset,
    ] = UNSET
    representing: Union[None, Unset, str] = UNSET
    statistics: Union[Unset, "CareerPersonRepresentationalStatisticsModelStatistics"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        age_group: Union[Unset, str] = UNSET
        if not isinstance(self.age_group, Unset):
            age_group = self.age_group.value

        discipline: Union[None, Unset, str]
        if isinstance(self.discipline, Unset):
            discipline = UNSET
        elif isinstance(self.discipline, CareerPersonRepresentationalStatisticsModelDisciplineType1):
            discipline = self.discipline.value
        elif isinstance(self.discipline, CareerPersonRepresentationalStatisticsModelDisciplineType2Type1):
            discipline = self.discipline.value
        elif isinstance(self.discipline, CareerPersonRepresentationalStatisticsModelDisciplineType3Type1):
            discipline = self.discipline.value
        else:
            discipline = self.discipline

        representing: Union[None, Unset, str]
        if isinstance(self.representing, Unset):
            representing = UNSET
        else:
            representing = self.representing

        statistics: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.statistics, Unset):
            statistics = self.statistics.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if age_group is not UNSET:
            field_dict["ageGroup"] = age_group
        if discipline is not UNSET:
            field_dict["discipline"] = discipline
        if representing is not UNSET:
            field_dict["representing"] = representing
        if statistics is not UNSET:
            field_dict["statistics"] = statistics

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.career_person_representational_statistics_model_organization import (
            CareerPersonRepresentationalStatisticsModelOrganization,
        )
        from ..models.career_person_representational_statistics_model_person import (
            CareerPersonRepresentationalStatisticsModelPerson,
        )
        from ..models.career_person_representational_statistics_model_statistics import (
            CareerPersonRepresentationalStatisticsModelStatistics,
        )

        d = dict(src_dict)
        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, CareerPersonRepresentationalStatisticsModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = CareerPersonRepresentationalStatisticsModelPerson.from_dict(_person)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, CareerPersonRepresentationalStatisticsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = CareerPersonRepresentationalStatisticsModelOrganization.from_dict(_organization)

        _age_group = d.pop("ageGroup", UNSET)
        age_group: Union[Unset, CareerPersonRepresentationalStatisticsModelAgeGroup]
        if isinstance(_age_group, Unset):
            age_group = UNSET
        else:
            age_group = CareerPersonRepresentationalStatisticsModelAgeGroup(_age_group)

        def _parse_discipline(
            data: object,
        ) -> Union[
            CareerPersonRepresentationalStatisticsModelDisciplineType1,
            CareerPersonRepresentationalStatisticsModelDisciplineType2Type1,
            CareerPersonRepresentationalStatisticsModelDisciplineType3Type1,
            None,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                discipline_type_1 = CareerPersonRepresentationalStatisticsModelDisciplineType1(data)

                return discipline_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                discipline_type_2_type_1 = CareerPersonRepresentationalStatisticsModelDisciplineType2Type1(data)

                return discipline_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                discipline_type_3_type_1 = CareerPersonRepresentationalStatisticsModelDisciplineType3Type1(data)

                return discipline_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    CareerPersonRepresentationalStatisticsModelDisciplineType1,
                    CareerPersonRepresentationalStatisticsModelDisciplineType2Type1,
                    CareerPersonRepresentationalStatisticsModelDisciplineType3Type1,
                    None,
                    Unset,
                ],
                data,
            )

        discipline = _parse_discipline(d.pop("discipline", UNSET))

        def _parse_representing(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        representing = _parse_representing(d.pop("representing", UNSET))

        _statistics = d.pop("statistics", UNSET)
        statistics: Union[Unset, CareerPersonRepresentationalStatisticsModelStatistics]
        if isinstance(_statistics, Unset):
            statistics = UNSET
        else:
            statistics = CareerPersonRepresentationalStatisticsModelStatistics.from_dict(_statistics)

        career_person_representational_statistics_model = cls(
            person_id=person_id,
            person=person,
            organization_id=organization_id,
            organization=organization,
            age_group=age_group,
            discipline=discipline,
            representing=representing,
            statistics=statistics,
        )

        return career_person_representational_statistics_model
